/**
 * 针对云阅卷场景多图片并行加载的工具
 * 1. 支持指定服务器地址
 * 2. 支持按云阅卷图片拼接规则筛选实际需要加载的图片
 * 3. 支持指定是否强制刷新图片
 * 
 * @param {*} option 
 */
function ImageLoader(option) {
    this.server = option.server || ''
    this.urls = option.urls || []
    this.config = option.config || []
    this.flush = option.flush === true
    this.onSuccess = option.onSuccess || (function() {})
    this.onError = option.onError || (function() {})
    this.start()
}

ImageLoader.prototype.start = function() {
    this.images = []
    this.needCount = 0
    this.successCount = 0
    for (let i = 0; i < this.urls.length; i++) {
        let image = new Image()
        this.images.push(image)
        if (this.needLoad(i + 1)) {
            this.needCount++

            image.parent = this
            image.crossOrigin = ''
            image.src = this.server + this.urls[i] + (this.flush ? ('?' + new Date().getTime()) : '')
            image.onload = function() {
                this.parent.successCount++
                if (this.parent.successCount == this.parent.needCount) {
                    this.parent.onFinish()
                }
            }
            image.onerror = function() {
                this.parent.onFinish(this.url + ' load error')
            }
        }
    }
}

ImageLoader.prototype.onFinish = function(error) {
    if (error) {
        this.onError(error)
    } else {
        this.onSuccess(this.images)
    }
}

ImageLoader.prototype.needLoad = function(number) {
    if (this.config != undefined && this.config.length > 0) {
        let find = false
        for (let i = 0; i < this.config.length; i++) {
            if (this.config[i].i == number) {
                find = true
                break
            }
        }
        return find
    } else {
        return true
    }
}